/**************************************************************
 * Structured Markov Chains Solver       [  SMCSolver  ]      *
 * Dario Bini, Beatrice Meini, Sergio Steffe'                 *
 * bini@dm.unipi.it, meini@dm.unipi.it, steffe@dm.unipi.it    *
 * Dipartimento di Matematica "Leonida Tonelli"               *
 * Largo Pontecorvo 5                                         *
 * 56127 Pisa                                                 *
 * Italy                                                      *
 * Version 2.1 - June  2009                                   *
 **************************************************************
 *
 *  main.h  
 *
 */

/* prototypes  main.c  */
static void usage(char *);
/* prototypes  interface.c */
GtkWidget * create_window_main( void );
/*  prototypes padwrite.c */
gint fifo_inwin(void);   
gint selection_uptodate(void);
/* prototypes examples.c */
void init_examples(void);
void parameters_setup(void);

/* globals */
int is_debug;
int is_smallscr;
char my_host_name[512];       /* hostname, used by various outputs */
char my_prog_name[512];       /* program name, used by various outputs */
GtkWidget *window_main;       /* main window */
struct parameters_str max[6],min[6],deflt[6],choice[6]; /* default parametres for each algorithm */

/*********************************************/
